@@ -55,7 +55,7 @@ def get_connection_values(response, **kwargs):
         provider_user_id=profile['id'],
         access_token=access_token,
         secret=None,
-        display_name=profile['username'],
+        display_name=profile.get('username', profile.get('name')),
         profile_url=profile_url,
         image_url=image_url
     )
